<?php
namespace Shahnewaz\CodeCanyonLicensor\Services;

use Storage;
use Carbon\Carbon;
use Monolog\Logger;
use Monolog\Handler\StreamHandler;
use Illuminate\Support\Facades\Log;

class LicenseService
{

    private $itemId;
    private $apiUrl;
    protected $logger;
    private $personalToken;
    private $config;
    

    public function __construct () {
        $logger = new Logger('LicenseService');
        $logger->pushHandler(new StreamHandler(storage_path('LicenseService.log'), Logger::INFO));
        $this->logger = $logger;

        $this->itemId = '';
        $this->apiUrl = 'https://api.envato.com/v3/market/author/sale?code=';
    }

    public function verifyLicense ($config) {
        $this->config = $config;
        $this->personalToken = config($this->config.'.licensor');
        // check license
        return true;
           
    }

    public function verifyPurchase ($config) {
        $this->config = $config;
        $this->personalToken = config($this->config.'.licensor');
        $purchaseCodeFile = config($this->config.'.purchase_code_file_name', 'purchase_code');
        $purchase = Storage::disk('storage')->exists($purchaseCodeFile);
        return $purchase;
    }

    public function hasLicense ($verify = false) {
        $license = Storage::disk('storage')->exists(config($this->config.'.license_file_name', 'lic'));
        if ($verify) {
            return $this->verifyLicenseCode();
        }
        return $license;
    }

    public function verifyLicenseCode () {
        $licenseFileName = config($this->config.'.license_file_name', 'lic');

        if (Storage::disk('storage')->exists($licenseFileName)) {
            $licenseCodeRaw = Storage::disk('storage')->get($licenseFileName);
            $licenseCode = sha1(trim($licenseCodeRaw));
            $storedLicense = sha1(trim(config($this->config.'.license')));
            if ($licenseCode === $storedLicense) {
                return true;
            } else {
                $this->logger->addInfo('An invalid license code ['.$licenseCodeRaw.'] was provided. ['.Carbon::now().']');
            }
        }
        
        return redirect()->route('licensor.not-licensed', $this->config)->send();
    }

}
